@@ -12,12 +12,14 @@ CLASS_DISAMBIGUATION = ['nslog:519']
 CLASS_CREATOR        = ['nslog:1022']
 CLASS_REFERENCE      = ['nslog:1968']
 CLASS_TAG            = ['nslog:7336', 'taglist']
+CLASS_CONTENT        = ['lemmaTitleH1', 'headline-1', 'headline-2', 'para']
 
 
 
 class Page(object):
 
     def __init__(self, string, encoding='utf-8'):
+
         url = 'http://baike.baidu.com/search/word'
         payload = None
 
@@ -34,13 +36,14 @@ class Page(object):
 
         # Exceptions
         if self.soup.find(class_=CLASS_DISAMBIGUATION):
-            raise DisambiguationError(string, self.get_inurls())
+            raise DisambiguationError(string.decode('utf-8'), self.get_inurls())
         if '百度百科尚未收录词条' in self.html:
             raise PageError(string)
 
 
     def get_info(self):
         """ Get informations of the page """
+
         info = {}
         title = self.soup.title.get_text()
         info['title'] = title[:title.rfind('_')]
@@ -48,7 +51,7 @@ class Page(object):
 
         try:
             info['last_modify_time'] = self.soup.find(id='lastModifyTime').get_text()
-            info['creator'] = self.soup.find(class_=CLASS_CREATOR.get_text())
+            info['creator'] = self.soup.find(class_=CLASS_CREATOR).get_text()
 
         finally:
             return info
@@ -56,17 +59,18 @@ class Page(object):
     
     def get_content(self):
         """ Get main content of a page """
-        content_list = self.soup.find_all(class_=['lemmaTitleH1', 'headline-1', 'headline-2', 'para'])
+
+        content_list = self.soup.find_all(class_=CLASS_CONTENT)
         content = []
 
         for text in content_list:
-            if 'lemmaTitleH1' in text.get('class'):
+            if CLASS_CONTENT[0] in text.get('class'):
                 content.append('==== %s ====\n\n'%text.get_text())
-            elif 'headline-1' in text.get('class'):
+            elif CLASS_CONTENT[1] in text.get('class'):
                 content.append('\n== %s ==\n'%text.get_text())
-            elif 'headline-2' in text.get('class'):
+            elif CLASS_CONTENT[2] in text.get('class'):
                 content.append('\n* %s *\n'%text.get_text())
-            elif 'para' in text.get('class'):
+            elif CLASS_CONTENT[3] in text.get('class'):
                 content.append('%s'%text.get_text())
 
         return '\n'.join(content)
@@ -74,29 +78,37 @@ class Page(object):
 
     def get_inurls(self):
         """ Get links inside a page """
+
         inurls = OrderedDict() 
         href = self.soup.find_all(href=re.compile('\/(sub)?view(\/[0-9]*)+.htm'))
+
         for url in href:
             inurls[url.get_text()] = 'http://baike.baidu.com%s'%url.get('href')
+
         return inurls
 
 
     def get_tags(self):
         """ Get tags of the page """
+
         tags = []
         for tag in self.soup.find_all(class_=CLASS_TAG):
             tags.append(tag.get_text())
+
         return tags
 
     
     def get_references(self):
         """ Get references of the page """
+
         references = []
+
         for ref in self.soup.find_all(class_=CLASS_REFERENCE):
             r = {}
             r['title'] = ref.get_text()
             r['url'] = ref.get('href')
             references.append(r)
+
         return references
 
 
@@ -117,12 +129,12 @@ class Search(object):
 
     def get_results(self):
         """ Get searching results """
+
         search_results = []
         items = self.soup.find_all(class_='f')      # get results items
 
         for item in items:
             result = {}
-
             a = item.find('a')                      
             title = a.get_text()                    # get result title
             title = title[:title.rfind('_')]
